==> igniteui-react-core-16.6.5.tgz: package/ES5/GroupDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GroupDataDescription } from "./GroupDataDescription";
var GroupDataDescriptionMetadata = /** @class */ (function (_super) {
    tslib_1.__extends(GroupDataDescriptionMetadata, _super);
    function GroupDataDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GroupDataDescriptionMetadata.b = function (a) {
        if (GroupDataDescriptionMetadata.a == null) {
            GroupDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GroupDataDescriptionMetadata.c(a, GroupDataDescriptionMetadata.a);
        }
    };
    GroupDataDescriptionMetadata.c = function (a, b) {
        b.item("GroupName", "String");
        b.item("GroupValueRef", "(w:GroupValue)DataRef");
        b.item("FormattedText", "String");
    };
    GroupDataDescriptionMetadata.d = function (a) {
        GroupDataDescriptionMetadata.b(a);
        a.n("GroupData", function () { return new GroupDataDescription(); });
        a.m("GroupData", GroupDataDescriptionMetadata.a);
    };
    GroupDataDescriptionMetadata.$t = markType(GroupDataDescriptionMetadata, 'GroupDataDescriptionMetadata');
    GroupDataDescriptionMetadata.a = null;
    return GroupDataDescriptionMetadata;
}(Base));
export { GroupDataDescriptionMetadata };

==> igniteui-react-core-16.11.4.tgz: package/ES5/GroupDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GroupDataDescription } from "./GroupDataDescription";
/**
 * @hidden
 */
var GroupDataDescriptionMetadata = /** @class */ (function (_super) {
    tslib_1.__extends(GroupDataDescriptionMetadata, _super);
    function GroupDataDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GroupDataDescriptionMetadata.b = function (a) {
        if (GroupDataDescriptionMetadata.a == null) {
            GroupDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GroupDataDescriptionMetadata.c(a, GroupDataDescriptionMetadata.a);
        }
    };
    GroupDataDescriptionMetadata.c = function (a, b) {
        b.item("GroupName", "String");
        b.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
        b.item("FormattedText", "String");
    };
    GroupDataDescriptionMetadata.d = function (a) {
        GroupDataDescriptionMetadata.b(a);
        a.n("GroupData", function () { return new GroupDataDescription(); });
        a.m("GroupData", GroupDataDescriptionMetadata.a);
    };
    GroupDataDescriptionMetadata.$t = markType(GroupDataDescriptionMetadata, 'GroupDataDescriptionMetadata');
    GroupDataDescriptionMetadata.a = null;
    return GroupDataDescriptionMetadata;
}(Base));
export { GroupDataDescriptionMetadata };
